pub fn encrypted_write(
data: Vec<u8>,
key: &LessSafeKey,
file: PathBuf,
) -> Result<(), EncryptedWriteError>Expand description
Write data encrypted to a file with a random nonce that will be
encoded in the file
pub fn encrypted_write(
data: Vec<u8>,
key: &LessSafeKey,
file: PathBuf,
) -> Result<(), EncryptedWriteError>Write data encrypted to a file with a random nonce that will be
encoded in the file