#[non_exhaustive]pub enum DecryptError {
CiphertextTooShort {
len: usize,
},
Open,
}Expand description
Why decrypt could not open a ciphertext.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CiphertextTooShort
The ciphertext is shorter than the nonce it must start with.
Open
The ciphertext could not be opened: it does not authenticate under the key (the key is wrong or the ciphertext was altered), it is too short to hold the tag, or it is longer than the cipher can process as one message.